@@ -37,14 +37,6 @@
 #include "config.h"
 #endif
 
-/*
- * Activate acceleration code or not.
- *
- *         WARNING BUGGY !!!
- * Yes, you activate it on your own risk.
- */
-#define USE_ACCEL 0
-
 /*
  * includes 
  */
@@ -58,7 +50,6 @@
 #include "vtypes.h"
 #include "vboard.h"
 #include "vmodes.h"
-#include "accel.h"
 #include "vramdac.h"
 #include "rendition_shadow.h"
 #include "vbe.h"
@@ -115,14 +106,14 @@ static Bool renditionPciProbe(DriverPtr drv, int entity_num,
 static Bool       renditionProbe(DriverPtr, int);
 #endif
 static Bool       renditionPreInit(ScrnInfoPtr, int);
-static Bool       renditionScreenInit(int, ScreenPtr, int, char **);
-static Bool       renditionSwitchMode(int, DisplayModePtr, int);
-static void       renditionAdjustFrame(int, int, int, int);
-static Bool       renditionEnterVT(int, int);
-static void       renditionLeaveVT(int, int);
-static void       renditionFreeScreen(int, int);
+static Bool       renditionScreenInit(SCREEN_INIT_ARGS_DECL);
+static Bool       renditionSwitchMode(SWITCH_MODE_ARGS_DECL);
+static void       renditionAdjustFrame(ADJUST_FRAME_ARGS_DECL);
+static Bool       renditionEnterVT(VT_FUNC_ARGS_DECL);
+static void       renditionLeaveVT(VT_FUNC_ARGS_DECL);
+static void       renditionFreeScreen(FREE_SCREEN_ARGS_DECL);
 
-static ModeStatus renditionValidMode(int, DisplayModePtr, Bool, int);
+static ModeStatus renditionValidMode(SCRN_ARG_TYPE, DisplayModePtr, Bool, int);
 static Bool renditionMapMem(ScrnInfoPtr pScreenInfo);
 static Bool renditionUnmapMem(ScrnInfoPtr pScreenInfo);
 #if 0
@@ -200,72 +191,6 @@ _X_EXPORT DriverRec RENDITION={
 #endif
 };
 
-static const char *vgahwSymbols[]={
-    "vgaHWBlankScreen",
-    "vgaHWDPMSSet",
-    "vgaHWFreeHWRec",
-    "vgaHWGetHWRec",
-    "vgaHWGetIOBase",
-    "vgaHWGetIndex",
-    "vgaHWLock",
-    "vgaHWMapMem",
-    "vgaHWProtect",
-    "vgaHWRestore",
-    "vgaHWSave",
-    "vgaHWSaveScreen",
-    "vgaHWUnlock",
-    "vgaHWHandleColormaps",
-    NULL
-};
-
-static const char *ramdacSymbols[] = {
-    "xf86CreateCursorInfoRec",
-    "xf86DestroyCursorInfoRec",
-    "xf86InitCursor",
-    NULL
-};
-
-#if defined(XFree86LOADER) || USE_ACCEL
-static const char *xaaSymbols[] = {
-    "XAACreateInfoRec",
-    "XAADestroyInfoRec",
-    "XAAInit",
-    NULL
-};
-#endif
-
-static const char *ddcSymbols[] = {
-    "xf86DoEDID_DDC1",
-    "xf86PrintEDID",
-    NULL
-};
-
-static const char *int10Symbols[] = {
-    "xf86FreeInt10",
-    "xf86InitInt10",
-    NULL
-};
-
-static const char *fbSymbols[]={
-    "fbScreenInit",
-    "fbPictureInit",
-    NULL
-};
-
-static const char *shadowfbSymbols[] = {
-    "ShadowFBInit",
-    NULL
-};
-
-static const char *vbeSymbols[] = {
-    "VBEInit",
-    "vbeDoEDID",
-    "vbeFree",
-    NULL
-};
-
-
-
 #ifdef XFree86LOADER
 
 /* Module loader interface */
@@ -297,9 +222,6 @@ renditionSetup(pointer Module, pointer Options, int *ErrorMajor,
     if (!Initialised) {
         Initialised = TRUE;
         xf86AddDriver(&RENDITION, Module, 1);
-        LoaderRefSymLists(vgahwSymbols, ramdacSymbols,
-			  fbSymbols, xaaSymbols, ddcSymbols, int10Symbols,
-			  shadowfbSymbols, vbeSymbols, NULL);
         return (pointer) TRUE;
     }
 
@@ -399,7 +321,7 @@ renditionProbe(DriverPtr drv, int flags)
                     renditionChipsets, renditionPCIchipsets, 
                     devSections, numDevSections, drv, &usedChips);
 
-	xfree(devSections);
+	free(devSections);
 	if (numUsed <= 0)
 	    return FALSE;
 
@@ -428,7 +350,7 @@ renditionProbe(DriverPtr drv, int flags)
 		foundScreen=TRUE;
 	    }
         }
-	xfree(usedChips);
+	free(usedChips);
     }
     return foundScreen;
 }
@@ -469,7 +391,7 @@ renditionGetRec(ScrnInfoPtr pScreenInfo)
     sleep(1);
 #endif
     if (!pScreenInfo->driverPrivate)
-        pScreenInfo->driverPrivate=xcalloc(sizeof(renditionRec), 1);
+        pScreenInfo->driverPrivate=calloc(sizeof(renditionRec), 1);
 
     /* perhaps some initialization? <ml> */
 
@@ -490,7 +412,7 @@ renditionFreeRec(ScrnInfoPtr pScreenInfo)
 #endif
     if (xf86LoaderCheckSymbol("vgaHWFreeHWRec"))
 	vgaHWFreeHWRec(pScreenInfo);
-    xfree(pScreenInfo->driverPrivate);
+    free(pScreenInfo->driverPrivate);
     pScreenInfo->driverPrivate=NULL;
 
 #ifdef DEBUG
@@ -597,8 +519,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
     if (xf86LoadSubModule(pScreenInfo, "int10")){
         xf86Int10InfoPtr pInt=NULL;
 
-        xf86LoaderReqSymLists(int10Symbols, NULL);
-
         xf86DrvMsg(pScreenInfo->scrnIndex, X_INFO, "Initializing int10\n");
         pInt = xf86InitInt10(pRendition->pEnt->index);
         xf86FreeInt10(pInt);
@@ -609,7 +529,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
     pRendition->PciInfo = xf86GetPciInfoForEntity(pRendition->pEnt->index);
     pRendition->pcitag= pciTag(pRendition->PciInfo->bus,
                pRendition->PciInfo->device, pRendition->PciInfo->func);
-#endif
 
     /*
      * XXX This could be refined if some VGA memory resources are not
@@ -620,11 +539,12 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
     if (xf86RegisterResources(pRendition->pEnt->index, NULL, ResExclusive))
          return FALSE;
 
+
     /* Operations for which memory access is required. */
     pScreenInfo->racMemFlags = RAC_FB | RAC_CURSOR;
     /* Operations for which I/O access is required. (XXX Check this) */
     pScreenInfo->racIoFlags = RAC_FB | RAC_COLORMAP | RAC_CURSOR | RAC_VIEWPORT;
-    
+#endif
     /* determine depth, bpp, etc. */
     if (!xf86SetDepthBpp(pScreenInfo, 0, 0, 0, Support32bppFb))
         return FALSE;
@@ -667,7 +587,7 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
     /* collect all of the options flags and process them */
 
     xf86CollectOptions(pScreenInfo, NULL);
-    if (!(pRendition->Options = xalloc(sizeof(renditionOptions))))
+    if (!(pRendition->Options = malloc(sizeof(renditionOptions))))
 	return FALSE;
     memcpy(pRendition->Options, renditionOptions, sizeof(renditionOptions));
     xf86ProcessOptions(pScreenInfo->scrnIndex, pScreenInfo->options, 
@@ -678,8 +598,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
     if (!xf86LoadSubModule(pScreenInfo, "fb"))
       return FALSE;
 
-    xf86LoaderReqSymLists(fbSymbols, NULL);
-
     /* determine colour weights */
     pScreenInfo->rgbBits=8;
     
@@ -727,17 +645,20 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
     if (!xf86LoadSubModule(pScreenInfo, "vgahw")){
         return FALSE;
     }
-    xf86LoaderReqSymLists(vgahwSymbols, NULL);
 
     if (!vgaHWGetHWRec(pScreenInfo))
         return FALSE;
 
     pvgaHW = VGAHWPTR(pScreenInfo);
     pvgaHW->MapSize = 0x00010000;       /* Standard 64kB VGA window */
+    vgaHWSetStdFuncs(pvgaHW);
     vgaHWGetIOBase(pvgaHW);             /* Get VGA I/O base */
 
-    pRendition->board.accel=0;
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 12
     pRendition->board.vgaio_base = pvgaHW->PIOOffset;
+#else
+    pRendition->board.vgaio_base = 0;
+#endif
     pRendition->board.io_base = pRendition->board.vgaio_base 
 #ifdef XSERVER_LIBPCIACCESS
 	+ pRendition->PciInfo->regions[1].base_addr;
@@ -827,7 +748,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
 		       "Oops, \"ShadowFB\" module loading failed, disabling ShadowFB!\n");
 	}
 	else{
-	    xf86LoaderReqSymLists(shadowfbSymbols, NULL);
 	    pRendition->board.shadowfb=TRUE;
 	    xf86DrvMsg(pScreenInfo->scrnIndex, X_INFO,
 		       "Using \"Shadow Framebuffer\"\n");
@@ -846,7 +766,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
       if (!xf86LoadSubModule(pScreenInfo, "ramdac")) {
 	return FALSE;
       }
-      xf86LoaderReqSymLists(ramdacSymbols, NULL);
     }
 
 #if 0
@@ -857,7 +776,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
 		   ("Loading of DDC library failed, skipping DDC-probe\n"));
       }
       else {
-	xf86LoaderReqSymLists(ddcSymbols, NULL);
 	pScreenInfo->monitor->DDC = renditionDDC(pScreenInfo);
       }
     }
@@ -874,7 +792,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
       }
       else {
 	  xf86MonPtr mon;
-	  xf86LoaderReqSymLists(ddcSymbols, NULL);
 	  mon = renditionProbeDDC(pScreenInfo, pRendition->pEnt->index);
 	  xf86PrintEDID(mon);
 	  xf86SetDDCproperties(pScreenInfo, mon);
@@ -896,8 +813,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
      * Validate the modes.  Note that the limits passed to
      * xf86ValidateModes() are VGA CRTC architectural limits.
      */
-    pScreenInfo->maxHValue = MAX_HTOTAL;
-    pScreenInfo->maxVValue = MAX_VTOTAL;
     nModes = xf86ValidateModes(pScreenInfo,
             pScreenInfo->monitor->Modes, pScreenInfo->display->modes,
             &renditionClockRange, NULL, 8, MAX_HDISPLAY, Rounding,
@@ -942,32 +857,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
       xf86DrvMsg(pScreenInfo->scrnIndex, X_CONFIG,
 		 "Software cursor selected\n");
 
-    /* Unmapping delayed until after micrcode loading */
-      /****************************************/
-      /* Reserve memory and load the microcode */
-      /****************************************/
-#if USE_ACCEL
-    if (!xf86ReturnOptValBool(pRendition->Options, OPTION_NOACCEL,0) &&
-	!pRendition->board.shadowfb) {
-	/* Load XAA if needed */
-	if (xf86LoadSubModule(pScreenInfo, "xaa")) {
-	    xf86LoaderReqSymLists(xaaSymbols, NULL);
-	    renditionMapMem(pScreenInfo);
-  	    RENDITIONAccelPreInit (pScreenInfo);
-	    renditionUnmapMem(pScreenInfo);
-	    pRendition->board.accel = TRUE;
-	} else     xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
-			      ("XAA module not found: "
-			       "Skipping acceleration\n"));
-    }
-    else
-      xf86DrvMsg(pScreenInfo->scrnIndex, X_CONFIG,
-		 ("Skipping acceleration on users request\n"));
-#else
-    xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
-	       ("Skipping acceleration\n"));
-#endif
-
 #ifdef DEBUG
     ErrorF("PreInit OK...!!!!\n");
     sleep(2);
@@ -1131,9 +1020,9 @@ renditionLeaveGraphics(ScrnInfoPtr pScreenInfo)
 
 /* Unravel the screen */
 static Bool
-renditionCloseScreen(int scrnIndex, ScreenPtr pScreen)
+renditionCloseScreen(CLOSE_SCREEN_ARGS_DECL)
 {
-    ScrnInfoPtr pScreenInfo = xf86Screens[scrnIndex];
+    ScrnInfoPtr pScreenInfo = xf86ScreenToScrn(pScreen);
     renditionPtr prenditionPriv=renditionGetRec(pScreenInfo);
     Bool Closed = TRUE;
 
@@ -1145,9 +1034,6 @@ renditionCloseScreen(int scrnIndex, ScreenPtr pScreen)
     if (prenditionPriv->board.hwcursor_used)
 	RenditionHWCursorRelease(pScreenInfo);
 
-    if (prenditionPriv->board.accel)
-	RENDITIONAccelNone(pScreenInfo);
-
     if (pScreenInfo->vtSema)
 	renditionLeaveGraphics(pScreenInfo);
 
@@ -1156,7 +1042,7 @@ renditionCloseScreen(int scrnIndex, ScreenPtr pScreen)
     if (prenditionPriv 
 	&& (pScreen->CloseScreen = prenditionPriv->CloseScreen)) {
         prenditionPriv->CloseScreen = NULL;
-        Closed = (*pScreen->CloseScreen)(scrnIndex, pScreen);
+        Closed = (*pScreen->CloseScreen)(CLOSE_SCREEN_ARGS);
     }
     
 #ifdef DEBUG
@@ -1178,15 +1064,16 @@ renditionDPMSSet(ScrnInfoPtr pScreen, int mode, int flags)
 }
 
 static Bool
-renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
+renditionScreenInit(SCREEN_INIT_ARGS_DECL)
 {
-    ScrnInfoPtr pScreenInfo = xf86Screens[scrnIndex];
+    ScrnInfoPtr pScreenInfo = xf86ScreenToScrn(pScreen);
     renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
     Bool Inited = FALSE;
     unsigned char *FBBase;
     VisualPtr visual;
     vgaHWPtr pvgaHW;
     int displayWidth,width,height;
+    int scrnIndex = pScreenInfo->scrnIndex;
 
 #ifdef DEBUG
     ErrorF("RENDITION: renditionScreenInit() called\n");
@@ -1221,8 +1108,8 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     /* blank the screen */
     renditionSaveScreen(pScreen, SCREEN_SAVER_ON);
 
-    (*pScreenInfo->AdjustFrame)(pScreenInfo->scrnIndex,
-				pScreenInfo->frameX0, pScreenInfo->frameY0, 0);
+    (*pScreenInfo->AdjustFrame)(ADJUST_FRAME_ARGS(pScreenInfo,
+						  pScreenInfo->frameX0, pScreenInfo->frameY0));
 
 
     miClearVisualTypes();
@@ -1246,7 +1133,7 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
 	pRendition->board.shadowPitch 
 	    = BitmapBytePad(pScreenInfo->bitsPerPixel * width);
 	pRendition->board.shadowPtr 
-	    = xalloc(pRendition->board.shadowPitch * height);
+	    = malloc(pRendition->board.shadowPitch * height);
 	displayWidth = pRendition->board.shadowPitch 
 	    / (pScreenInfo->bitsPerPixel >> 3);
 	FBBase = pRendition->board.shadowPtr;
@@ -1284,16 +1171,11 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     fbPictureInit (pScreen, 0, 0);
 
     xf86SetBlackWhitePixels(pScreen);
-    miInitializeBackingStore(pScreen);
    
     /*********************************************************/
     /* The actual setup of the driver-specific code          */
     /* has to be after fbScreenInit and before cursor init */
     /*********************************************************/
-#if USE_ACCEL
-    if (pRendition->board.accel) 
-	RENDITIONAccelXAAInit (pScreen);
-#endif
 
     /* Initialise cursor functions */
     xf86SetSilkenMouse(pScreen);
@@ -1302,7 +1184,7 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     if(!xf86ReturnOptValBool(pRendition->Options, OPTION_SW_CURSOR,0)&&
        !pRendition->board.rotate){
 	/* Initialise HW cursor */
-	if(!RenditionHWCursorInit(scrnIndex, pScreen)){
+	if(!RenditionHWCursorInit(pScreen)){
 	    xf86DrvMsg(pScreenInfo->scrnIndex, X_ERROR,
 		       "Hardware Cursor initalization failed!!\n");
 	}
@@ -1354,7 +1236,7 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     pScreen->SaveScreen = renditionSaveScreen;
 
     if (!Inited)
-        renditionCloseScreen(scrnIndex, pScreen);
+        renditionCloseScreen(CLOSE_SCREEN_ARGS);
 
     if (serverGeneration == 1)
 	xf86ShowUnusedOptions(pScreenInfo->scrnIndex, pScreenInfo->options);
@@ -1367,19 +1249,20 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
 }
 
 static Bool
-renditionSwitchMode(int scrnIndex, DisplayModePtr pMode, int flags)
+renditionSwitchMode(SWITCH_MODE_ARGS_DECL)
 {
+    SCRN_INFO_PTR(arg);
 #ifdef DEBUG
     ErrorF("RENDITION: renditionSwitchMode() called\n");
 #endif
-    return renditionSetMode(xf86Screens[scrnIndex], pMode);
+    return renditionSetMode(pScreenInfo, mode);
 }
 
 
 static void
-renditionAdjustFrame(int scrnIndex, int x, int y, int flags)
+renditionAdjustFrame(ADJUST_FRAME_ARGS_DECL)
 {
-    ScrnInfoPtr pScreenInfo=xf86Screens[scrnIndex];
+    SCRN_INFO_PTR(arg);
     renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
     int offset, virtualwidth, bitsPerPixel;
 
@@ -1401,9 +1284,9 @@ renditionAdjustFrame(int scrnIndex, int x, int y, int flags)
 
 
 static Bool
-renditionEnterVT(int scrnIndex, int flags)
+renditionEnterVT(VT_FUNC_ARGS_DECL)
 {
-    ScrnInfoPtr pScreenInfo = xf86Screens[scrnIndex];
+    SCRN_INFO_PTR(arg);
     vgaHWPtr pvgaHW = VGAHWPTR(pScreenInfo);
 
 #ifdef DEBUG
@@ -1420,37 +1303,45 @@ renditionEnterVT(int scrnIndex, int flags)
     if (!renditionSetMode(pScreenInfo, pScreenInfo->currentMode))
         return FALSE;
 
-    (*pScreenInfo->AdjustFrame)(pScreenInfo->scrnIndex,
-				pScreenInfo->frameX0, pScreenInfo->frameY0, 0);
+    (*pScreenInfo->AdjustFrame)(ADJUST_FRAME_ARGS(pScreenInfo,
+						  pScreenInfo->frameX0, pScreenInfo->frameY0));
 
     return TRUE;
 }
 
 
 static void
-renditionLeaveVT(int scrnIndex, int flags)
+renditionLeaveVT(VT_FUNC_ARGS_DECL)
 {
+    SCRN_INFO_PTR(arg);
 #ifdef DEBUG
     ErrorF("RENDITION: renditionLeaveVT() called\n");
 #endif
-    renditionLeaveGraphics(xf86Screens[scrnIndex]);
+    renditionLeaveGraphics(pScreenInfo);
 }
 
 
 static void
-renditionFreeScreen(int scrnIndex, int flags)
+renditionFreeScreen(FREE_SCREEN_ARGS_DECL)
 {
-    renditionFreeRec(xf86Screens[scrnIndex]);
+    SCRN_INFO_PTR(arg);
+    renditionFreeRec(pScreenInfo);
 }
 
 
 static ModeStatus
-renditionValidMode(int scrnIndex, DisplayModePtr pMode, Bool Verbose, 
+renditionValidMode(SCRN_ARG_TYPE arg, DisplayModePtr pMode, Bool Verbose, 
 		   int flags)
 {
     if (pMode->Flags & V_INTERLACE)
         return MODE_NO_INTERLACE;
 
+    if (pMode->HTotal > MAX_HTOTAL)
+        return MODE_BAD_HVALUE;
+
+    if (pMode->VTotal > MAX_VTOTAL)
+        return MODE_BAD_VVALUE;
+
     return MODE_OK;
 }
 
@@ -1484,6 +1375,18 @@ renditionMapMem(ScrnInfoPtr pScreenInfo)
        /* Override on users request */
     WriteCombine
 	= xf86ReturnOptValBool(pRendition->Options, OPTION_FBWC, WriteCombine);
+#ifdef XSERVER_LIBPCIACCESS
+    mapOption = PCI_DEV_MAP_FLAG_WRITABLE;
+    if (WriteCombine)
+	mapOption |= PCI_DEV_MAP_FLAG_WRITE_COMBINE;
+
+    err = pci_device_map_range(pRendition->PciInfo,
+			       pRendition->PciInfo->regions[0].base_addr,
+			       pRendition->PciInfo->regions[0].size,
+			       mapOption, (void *)&pRendition->board.vmem_base);
+
+    return (err == 0);
+#else
     if (WriteCombine) {
 	xf86DrvMsg(pScreenInfo->scrnIndex, X_CONFIG,
 		   ("Requesting Write-Combined memory access\n"));
@@ -1494,12 +1397,6 @@ renditionMapMem(ScrnInfoPtr pScreenInfo)
 	mapOption = VIDMEM_MMIO;
     }
 
-#ifdef XSERVER_LIBPCIACCESS
-    err = pci_device_map_region(pRendition->PciInfo, 0, TRUE);
-    pRendition->board.vmem_base = pRendition->PciInfo->regions[0].memory;
-
-    return (err == 0);
-#else
     pRendition->board.vmem_base=
         xf86MapPciMem(pScreenInfo->scrnIndex, mapOption,
 		      pRendition->pcitag,
@@ -1528,7 +1425,7 @@ renditionUnmapMem(ScrnInfoPtr pScreenInfo)
 #else
     pci_device_unmap_range(pRendition->PciInfo, 
 			   pRendition->board.vmem_base,
-			   pScreenInfo->videoRam * 1024);
+			   pRendition->PciInfo->regions[0].size);
 #endif
     return TRUE;
 #ifdef DEBUG0
@@ -1551,8 +1448,6 @@ renditionProbeDDC(ScrnInfoPtr pScreenInfo, int index)
   xf86MonPtr mon = NULL;
 
   if (xf86LoadSubModule(pScreenInfo, "vbe")) {
-    xf86LoaderReqSymLists(vbeSymbols, NULL);
-
     pVbe = VBEInit(NULL,index);
     mon = vbeDoEDID(pVbe, NULL);
     vbeFree(pVbe);
@@ -1565,7 +1460,7 @@ static xf86MonPtr
 renditionDDC (ScrnInfoPtr pScreenInfo)
 {
   renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
-  IOADDRESS iob=pRendition->board.io_base;
+  unsigned long iob=pRendition->board.io_base;
   vu32 temp;
 
   xf86MonPtr MonInfo = NULL;
@@ -1598,7 +1493,7 @@ static unsigned int
 renditionDDC1Read (ScrnInfoPtr pScreenInfo)
 {
   renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
-  IOADDRESS iob=pRendition->board.io_base;
+  unsigned long iob=pRendition->board.io_base;
   vu32 value = 0;
 
   /* wait for Vsync */
